<?php
/*
Plugin Name: WooCommerce Print Order (EasyToolsWP)
Description: Adds a print order button to WooCommerce orders.
Version: 1.1
Author: EasyToolsWP.com
Author URI: https://www.easytoolswp.com
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Enqueue JavaScript and CSS files for admin
add_action('admin_enqueue_scripts', 'etwp_wc_print_order_enqueue_scripts');
function etwp_wc_print_order_enqueue_scripts($hook) {
    global $post_type;

    // Only enqueue scripts on WooCommerce order edit pages
    if ('shop_order' === $post_type && 'post' === $hook) {
        wp_enqueue_script('etwp-wc-print-order-script', plugin_dir_url(__FILE__) . 'etwp-wc-print-order.js', array('jquery'), '1.0', true);
        wp_localize_script('etwp-wc-print-order-script', 'etwp_wc_print_order', array(
            'nonce' => wp_create_nonce('etwp_wc_print_order_nonce')
        ));
        wp_enqueue_style('etwp-wc-print-order-style', plugin_dir_url(__FILE__) . 'etwp-print-style.css');
    }
}

// Add Print Order button to actions column
add_filter('woocommerce_admin_order_actions', 'etwp_wc_print_order_add_order_actions', 10, 2);
function etwp_wc_print_order_add_order_actions($actions, $order) {
    $actions['print_order'] = array(
        'url'    => wp_nonce_url(admin_url('admin-ajax.php?action=etwp_wc_print_order&id=' . $order->get_id()), 'etwp_wc_print_order_nonce'),
        'name'   => __('Print Order', 'etwp-wc'),
        'action' => 'print_order',
    );
    return $actions;
}

// Handle AJAX request for printing order
add_action('wp_ajax_etwp_wc_print_order', 'etwp_wc_print_order_callback');
function etwp_wc_print_order_callback() {
    check_ajax_referer('etwp_wc_print_order_nonce', 'nonce');

    $order_id = absint($_GET['id']);
    $order = wc_get_order($order_id);

    // Get logo URL from settings
    $logo_url = get_option('etwp_wc_print_order_logo_url', '');

    // Start output buffering to capture HTML
    ob_start();
    ?>
    <html>
    <head>
        <link rel="stylesheet" type="text/css" href="<?php echo plugin_dir_url(__FILE__); ?>etwp-print-style.css">
        <style>
            body { background-color: <?php echo esc_attr(get_option('etwp_wc_print_order_background_color', '#eee')); ?>; }
            .order-container { font-family: Arial, sans-serif; background-color: #fff; border: 1px solid #ddd; font-size: 14px !important; }
            .header { padding: 20px; }
            .header img { max-width: 200px; } /* Adjust logo size as needed */
        </style>
    </head>
    <body>
        <div class="order-container">
            <div class="header">
                <?php if (!empty($logo_url)) : ?>
                    <img src="<?php echo esc_url($logo_url); ?>" alt="Logo">
                <?php endif; ?>
                <h1><?php echo etwp_wc_translate_text('order_heading', 'Order Details'); ?></h1>
            </div>
            <div class="order-details">
                <h2><?php echo etwp_wc_translate_text('order_number_label', 'Order #'); ?><?php echo $order->get_order_number(); ?></h2>
                <dl class="order-meta">
                    <dt><?php echo etwp_wc_translate_text('order_date_label', 'Order Date:'); ?></dt>
                    <dd><?php echo wc_format_datetime($order->get_date_created()); ?></dd>
                    <dt><?php echo etwp_wc_translate_text('email_label', 'Email:'); ?></dt>
                    <dd><?php echo $order->get_billing_email(); ?></dd>
                    <dt><?php echo etwp_wc_translate_text('phone_label', 'Phone:'); ?></dt>
                    <dd><?php echo $order->get_billing_phone(); ?></dd>
                    <dt><?php echo etwp_wc_translate_text('shipping_address_label', 'Shipping Address:'); ?></dt>
                    <dd><?php echo $order->get_formatted_shipping_address(); ?></dd>
                    <dt><?php echo etwp_wc_translate_text('billing_address_label', 'Billing Address:'); ?></dt>
                    <dd><?php echo $order->get_formatted_billing_address(); ?></dd>
                    <?php
                    // Check if order has downloadable files
                    $has_downloads = false;
                    foreach ($order->get_items() as $item_id => $item) {
                        if ($item->is_type('line_item')) {
                            $product = $item->get_product();
                            if ($product && $product->is_downloadable()) {
                                $has_downloads = true;
                                break;
                            }
                        }
                    }
                    if ($has_downloads) {
                        ?>
                        <div class="downloadableinvoice"><?php echo etwp_wc_translate_text('find_download_text', 'Find your download on our website > your account'); ?></div>
                        <?php
                    }
                    ?>
                </dl>
            </div>
            <div class="order-items">
                <h2><?php echo etwp_wc_translate_text('items_label', 'Items'); ?></h2>
                <table width="100%">
                    <thead>
                        <tr>
                            <th><?php echo etwp_wc_translate_text('product_label', 'Product'); ?></th>
                            <?php if (etwp_wc_has_skus($order)) : ?>
                                <th><?php _e('Product Number', 'etwp-wc'); ?></th>
                            <?php endif; ?>
                            <th><?php _e('Quantity', 'etwp-wc'); ?></th>
                            <th class="align-right"><?php echo etwp_wc_translate_text('total_label', 'Total'); ?></th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        foreach ($order->get_items() as $item_id => $item) {
                            // Exclude certain meta data
                            $exclude_meta = array('_wapf_meta');
                            ?>
                            <tr>
                                <td>
                                    <?php echo $item->get_name(); ?>
                                    <dl>
                                        <?php
                                        foreach ($item->get_meta_data() as $meta) {
                                            if (!in_array($meta->key, $exclude_meta)) {
                                                echo '<dt>' . esc_html($meta->key) . ':</dt> <dd>' . esc_html($meta->value) . '</dd>';
                                            }
                                        }
                                        ?>
                                    </dl>
                                </td>
                                <?php if (etwp_wc_has_skus($order)) : ?>
                                    <td><?php echo $item->get_product()->get_sku(); ?></td>
                                <?php endif; ?>
                                <td><?php echo $item->get_quantity(); ?></td>
                                <td class="align-right"><?php echo wc_price($item->get_total()); ?></td>
                            </tr>
                            <?php
                        }
                        ?>
                    </tbody>
                </table>
            </div>
            <div class="order-summary">
                <h2><?php echo etwp_wc_translate_text('order_summary_label', 'Order Summary'); ?></h2>
                <dl>
                    <dt><?php echo etwp_wc_translate_text('items_total_label', 'Items Total:'); ?></dt>
                    <dd><?php echo wc_price($order->get_subtotal()); ?></dd>
                    <dt><?php echo etwp_wc_translate_text('shipping_label', 'Shipping:'); ?></dt>
                    <dd><?php echo wc_price($order->get_shipping_total()); ?> (<?php echo $order->get_shipping_method(); ?>)</dd>
                    <dt><?php echo etwp_wc_translate_text('payment_method_label', 'Payment Method:'); ?></dt>
                    <dd><?php echo $order->get_payment_method_title(); ?></dd>
                    <dt><?php echo etwp_wc_translate_text('order_total_label', 'Order Total:'); ?></dt>
                    <dd><?php echo wc_price($order->get_total()); ?></dd>
                </dl>
            </div>
            <div class="footer">
                <p><?php echo etwp_wc_translate_text('thank_you_text', 'Thank you for your business!'); ?></p>
            </div>
        </div>
    </body>
    </html>
    <?php
    $html = ob_get_clean();
    echo $html;

    wp_die();
}

// Function to retrieve translated text
function etwp_wc_translate_text($key, $default) {
    $options = get_option('etwp_wc_print_order_translate_settings');
    $value = isset($options[$key]) ? $options[$key] : '';

    // Return default if translation is empty
    return !empty($value) ? $value : $default;
}

// Function to check if SKU is available in any item
function etwp_wc_has_skus($order) {
    foreach ($order->get_items() as $item_id => $item) {
        if ($item->get_product()->get_sku()) {
            return true;
        }
    }
    return false;
}

// Add settings page
add_action('admin_menu', 'etwp_wc_print_order_settings_page');
function etwp_wc_print_order_settings_page() {
    add_menu_page(
        __('Print Order Settings', 'etwp-wc'),
        __('Print Order', 'etwp-wc'),
        'manage_options',
        'etwp-wc-print-order-settings',
        'etwp_wc_print_order_settings_redirect',
        'dashicons-printer'
    );
	
// Redirect function for the menu item
function etwp_wc_print_order_settings_redirect() {
    $redirect_url = 'https://www.easytoolswp.com/wp-admin/admin.php?page=etwp-wc-print-order-appearance';
    wp_redirect($redirect_url);
    exit;
}

    // Add submenu items for tabs
    add_submenu_page(
        'etwp-wc-print-order-settings',
        __('Translate', 'etwp-wc'),
        __('Translate', 'etwp-wc'),
        'manage_options',
        'etwp-wc-print-order-translate',
        'etwp_wc_print_order_translate_page_content'
    );

    // Add submenu item for appearance settings
    add_submenu_page(
        'etwp-wc-print-order-settings',
        __('Appearance', 'etwp-wc'),
        __('Appearance', 'etwp-wc'),
        'manage_options',
        'etwp-wc-print-order-appearance',
        'etwp_wc_print_order_appearance_page_content'
    );
}

add_action('admin_head', 'etwp_wc_custom_admin_css');
function etwp_wc_custom_admin_css() {
    ?>
    <style>
        #toplevel_page_etwp-wc-print-order-settings .wp-first-item {
            display: none;
        }
    </style>
    <?php
}

// Callback function to display translate settings page content
function etwp_wc_print_order_translate_page_content() {
    ?>
    <div class="wrap">
        <h1><?php _e('Translate Order Texts', 'etwp-wc'); ?></h1>

        <form method="post" action="options.php">
            <?php settings_fields('etwp_wc_print_order_translate_settings_group'); ?>
            <?php do_settings_sections('etwp-wc-print-order-translate'); ?>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Callback function to display appearance settings page content
function etwp_wc_print_order_appearance_page_content() {
    ?>
    <div class="wrap">
        <h1><?php _e('Print Order Appearance', 'etwp-wc'); ?></h1>

        <form method="post" action="options.php">
            <?php settings_fields('etwp_wc_print_order_appearance_settings_group'); ?>
            <?php do_settings_sections('etwp-wc-print-order-appearance'); ?>

            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Register settings and sections for translation settings
add_action('admin_init', 'etwp_wc_print_order_register_translate_settings');
function etwp_wc_print_order_register_translate_settings() {
    register_setting('etwp_wc_print_order_translate_settings_group', 'etwp_wc_print_order_translate_settings');

    add_settings_section(
        'etwp_wc_print_order_translate_section',
        __('Translation Settings', 'etwp-wc'),
        'etwp_wc_print_order_translate_section_callback',
        'etwp-wc-print-order-translate'
    );

    // Add fields for each text to translate
    $fields = array(
        'order_heading' => __('Order', 'etwp-wc'),
        'order_date_label' => __('Order Date:', 'etwp-wc'),
        'email_label' => __('Email:', 'etwp-wc'),
        'phone_label' => __('Phone:', 'etwp-wc'),
        'shipping_address_label' => __('Shipping Address:', 'etwp-wc'),
        'billing_address_label' => __('Billing Address:', 'etwp-wc'),
        'find_download_text' => __('Find your download on our website > your account', 'etwp-wc'),
        'items_label' => __('Items', 'etwp-wc'),
        'product_label' => __('Product', 'etwp-wc'),
        'total_label' => __('Total', 'etwp-wc'),
        'order_summary_label' => __('Order Summary', 'etwp-wc'),
        'items_total_label' => __('Items Total:', 'etwp-wc'),
        'shipping_label' => __('Shipping:', 'etwp-wc'),
        'payment_method_label' => __('Payment Method:', 'etwp-wc'),
        'order_total_label' => __('Order Total:', 'etwp-wc'),
        'thank_you_text' => __('Thank you for your business!', 'etwp-wc'),
        'quantity_label' => __('Quantity', 'etwp-wc'), // Added field for Quantity label translation
        'sku_label' => __('Product Number', 'etwp-wc') // Added field for SKU label translation
    );

    foreach ($fields as $key => $label) {
        add_settings_field(
            'etwp_wc_print_order_translate_' . $key,
            $label,
            'etwp_wc_print_order_translate_field_callback',
            'etwp-wc-print-order-translate',
            'etwp_wc_print_order_translate_section',
            array('key' => $key, 'label' => $label)
        );
    }
}

// Callback function to display translate settings fields
function etwp_wc_print_order_translate_field_callback($args) {
    $options = get_option('etwp_wc_print_order_translate_settings');
    $key = $args['key'];
    $value = isset($options[$key]) ? esc_attr($options[$key]) : '';
    echo '<input type="text" id="etwp_wc_print_order_translate_' . $key . '" name="etwp_wc_print_order_translate_settings[' . $key . ']" value="' . $value . '" />';
}

// Callback function for translation settings section
function etwp_wc_print_order_translate_section_callback() {
    echo '<p>' . __('Enter translations for order texts.', 'etwp-wc') . '</p>';
}

// Register settings and sections for appearance settings
add_action('admin_init', 'etwp_wc_print_order_register_appearance_settings');
function etwp_wc_print_order_register_appearance_settings() {
    register_setting('etwp_wc_print_order_appearance_settings_group', 'etwp_wc_print_order_background_color');
    register_setting('etwp_wc_print_order_appearance_settings_group', 'etwp_wc_print_order_logo_url'); // Register logo URL setting

    add_settings_section(
        'etwp_wc_print_order_appearance_section',
        __('Appearance Settings', 'etwp-wc'),
        'etwp_wc_print_order_appearance_section_callback',
        'etwp-wc-print-order-appearance'
    );

    add_settings_field(
        'etwp_wc_print_order_background_color',
        __('Background Color', 'etwp-wc'),
        'etwp_wc_print_order_background_color_field_callback',
        'etwp-wc-print-order-appearance',
        'etwp_wc_print_order_appearance_section'
    );

    // Add field for logo URL
    add_settings_field(
        'etwp_wc_print_order_logo_url',
        __('Logo URL', 'etwp-wc'),
        'etwp_wc_print_order_logo_url_field_callback',
        'etwp-wc-print-order-appearance',
        'etwp_wc_print_order_appearance_section'
    );
}

// Callback function to display appearance settings fields
function etwp_wc_print_order_background_color_field_callback() {
    $color = get_option('etwp_wc_print_order_background_color', '#eee');
    echo '<input type="text" id="etwp_wc_print_order_background_color" name="etwp_wc_print_order_background_color" value="' . esc_attr($color) . '" />';
}

// Callback function for logo URL field
function etwp_wc_print_order_logo_url_field_callback() {
    $logo_url = get_option('etwp_wc_print_order_logo_url', '');
    echo '<input type="text" id="etwp_wc_print_order_logo_url" name="etwp_wc_print_order_logo_url" value="' . esc_url($logo_url) . '" />';
}

// Callback function for appearance settings section
function etwp_wc_print_order_appearance_section_callback() {
    echo '<p>' . __('Customize the appearance of the print order page.', 'etwp-wc') . '</p>';
}

// Enqueue JavaScript for handling print order button
add_action('admin_footer', 'etwp_wc_print_order_script');
function etwp_wc_print_order_script() {
    ?>
    <script type="text/javascript">
        jQuery(document).ready(function($) {
            // Append Print Order button to each order row
            $('.column-order_actions').each(function() {
                var order_id = $(this).find('.order-view').attr('href').replace('post.php?post=', '').replace('&action=edit', '');
                var print_url = '<?php echo wp_nonce_url(admin_url('admin-ajax.php?action=etwp_wc_print_order&id=')); ?>' + order_id;

                $(this).append('<a href="' + print_url + '" class="button print_order" target="_blank"><?php _e('Print Order', 'etwp-wc'); ?></a>');
            });

            // AJAX handler for Print Order
            $('body').on('click', '.print_order', function(e) {
                e.preventDefault();

                var print_url = $(this).attr('href');

                var newTab = window.open(print_url, '_blank');
                if (newTab) {
                    newTab.focus();
                } else {
                    alert('<?php _e('Please allow popups for this site', 'etwp-wc'); ?>');
                }
            });
        });
    </script>
    <?php
}
?>
